**Example 1: 删除商业智能平面文件**



Input: 

```
tccli sqlserver DeleteBusinessIntelligenceFile --cli-unfold-argument  \
    --InstanceId mssqlbi-fo2dwujt \
    --FileNameSet test.xlsx
```

Output: 
```
{
    "Response": {
        "RequestId": "b2231cb2-9415-46af-b48f-bab65e06b091"
    }
}
```

